@@ -1,11 +1,14 @@
 #!/usr/bin/env python3
 
 import json, toml, yaml, nestedtext as nt
+import functools
 
+@functools.wraps(json.load)
 def _load_json(path):
     with open(path) as f:
         return json.load(f)
 
+@functools.wraps(yaml.safe_load)
 def _load_yml(path):
     with open(path) as f:
         return yaml.safe_load(f)
